jaclearn.nlp.graph.dependency\_visualizer.utils
===============================================

.. automodule:: jaclearn.nlp.graph.dependency_visualizer.utils

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      escape_html
      minify_html
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: escape_html

.. autofunction:: minify_html


